@@ -1029,7 +1029,7 @@ cm_FindServerByUuid(afsUUID *serverUuid, int type, int locked)
         lock_ObtainRead(&cm_serverLock);
 
     for (tsp = cm_allServersp; tsp; tsp = tsp->allNextp) {
-        if (tsp->type == type && !afs_uuid_equal(&tsp->uuid, serverUuid))
+	if (tsp->type == type && afs_uuid_equal(&tsp->uuid, serverUuid))
             break;
     }
 
@@ -1593,7 +1593,7 @@ int cm_DumpServers(FILE *outputFile, char *cookie, int lock)
                  cookie, tsp, tsp->cellp ? tsp->cellp->name : "", hoststr,
                  ntohs(tsp->addr.sin_port), uuidstr, type,
                  tsp->capabilities, tsp->flags, tsp->waitCount, tsp->activeRank,
-                 (tsp->flags & CM_SERVERFLAG_DOWN) ?  down : "up",
+                 (tsp->flags & CM_SERVERFLAG_DOWN) ?  "down" : "up",
                  tsp->refCount);
         WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
     }
@@ -1629,7 +1629,7 @@ int cm_ServerEqual(cm_server_t *srv1, cm_server_t *srv2)
         if (UuidEqual((UUID *)&srv1->uuid, (UUID *)&srv2->uuid, &status))
             return 1;
     } else {
-        if (srv1->flags & CM_SERVERFLAG_UUID)
+        if (srv2->flags & CM_SERVERFLAG_UUID)
             return 0;
 
         /* Neither support UUID so perform an addr/port comparison */
