@@ -59,18 +59,20 @@ cm_ValidateVolume(void)
             return -2;
         }
 
-	if ( volp->allNextp < (cm_volume_t *)cm_data.volumeBaseAddress ||
-	     volp->allNextp >= (cm_volume_t *)cm_data.cellBaseAddress) {
-	    afsi_log("cm_ValidateVolume failure: out of range cm_volume_t pointers");
-	    fprintf(stderr, "cm_ValidateVolume failure: out of range cm_volume_t pointers\n");
-	    return -12;
-	}
+	if ( volp->allNextp) {
+	    if ( volp->allNextp < (cm_volume_t *)cm_data.volumeBaseAddress ||
+		 volp->allNextp >= (cm_volume_t *)cm_data.cellBaseAddress) {
+		afsi_log("cm_ValidateVolume failure: out of range cm_volume_t pointers");
+		fprintf(stderr, "cm_ValidateVolume failure: out of range cm_volume_t pointers\n");
+		return -12;
+	    }
 
-        if ( volp->allNextp && volp->allNextp->magic != CM_VOLUME_MAGIC ) {
-            afsi_log("cm_ValidateVolume failure: volp->allNextp->magic != CM_VOLUME_MAGIC");
-            fprintf(stderr, "cm_ValidateVolume failure: volp->allNextp->magic != CM_VOLUME_MAGIC\n");
-            return -3;
-        }
+	    if ( volp->allNextp->magic != CM_VOLUME_MAGIC ) {
+		afsi_log("cm_ValidateVolume failure: volp->allNextp->magic != CM_VOLUME_MAGIC");
+		fprintf(stderr, "cm_ValidateVolume failure: volp->allNextp->magic != CM_VOLUME_MAGIC\n");
+		return -3;
+	    }
+	}
 
         if ( count != 0 && volp == cm_data.allVolumesp ||
              count > cm_data.maxVolumes ) {
@@ -793,6 +795,24 @@ cm_volume_t *cm_GetVolumeByFID(cm_fid_t *fidp)
     return volp;
 }
 
+cm_volume_t *cm_FindVolumeByFID(cm_fid_t *fidp, cm_user_t *userp, cm_req_t *reqp)
+{
+    cm_volume_t *volp = NULL;
+    cm_cell_t   *cellp;
+    long         code;
+
+    cellp = cm_FindCellByID(fidp->cell, CM_FLAG_NOPROBE);
+    if (!cellp) {
+	return NULL;
+    }
+
+    code = cm_FindVolumeByID(cellp, fidp->volume, userp, reqp, CM_GETVOL_FLAG_CREATE, &volp);
+    if (code)
+	return NULL;
+
+    return volp;
+}
+
 long cm_FindVolumeByID(cm_cell_t *cellp, afs_uint32 volumeID, cm_user_t *userp,
                       cm_req_t *reqp, afs_uint32 flags, cm_volume_t **outVolpp)
 {
