@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -40,10 +40,10 @@ typedef unsigned short etap_event_t;
 #include "h/systm.h"
 #endif
 #include "h/time.h"
-#ifdef AFS_SUN56_ENV
-#include "h/vfs.h"		/* stops SUN56 socketvar.h warnings */
-#include "h/stropts.h"		/* stops SUN56 socketvar.h warnings */
-#include "h/stream.h"		/* stops SUN56 socketvar.h errors */
+#ifdef AFS_SUN5_ENV
+#include "h/vfs.h"		/* stops SUN5 socketvar.h warnings */
+#include "h/stropts.h"		/* stops SUN5 socketvar.h warnings */
+#include "h/stream.h"		/* stops SUN5 socketvar.h errors */
 #include "h/disp.h"
 #endif
 #include "h/socket.h"
@@ -63,12 +63,14 @@ typedef unsigned short etap_event_t;
 #include "h/dirent.h"
 #include "h/socket.h"
 #include "h/domain.h"
-#if defined(AFS_FBSD50_ENV)
 #include "h/bio.h"
-#endif
 #include "h/buf.h"
 #include "h/mbuf.h"
 #endif /* AFS_FBSD_ENV */
+#if defined(AFS_NBSD40_ENV)
+#include "h/buf.h"
+#include "h/mbuf.h"
+#endif
 #endif /* !defined(AFS_SUN5_ENV) && !defined(AFS_XBSD_ENV) */
 #endif /* !defined(AFS_LINUX22_ENV) && !defined(AFS_OBSD_ENV) */
 #ifdef AFS_SGI62_ENV
@@ -94,17 +96,17 @@ typedef unsigned short etap_event_t;
 #include "netinet/in_systm.h"
 #endif
 #include "netinet/ip.h"
-#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN60_ENV) && !defined(AFS_OBSD_ENV)
+#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_OBSD_ENV)
 #include "netinet/in_pcb.h"
 #endif /* ! AFS_HPUX110_ENV && ! AFS_LINUX22_ENV */
 #ifndef AFS_LINUX22_ENV
-#if !defined(AFS_DARWIN60_ENV)
+#if !defined(AFS_DARWIN_ENV)
 #include "netinet/ip_var.h"
 #endif
 #include "netinet/ip_icmp.h"
 #endif /* AFS_LINUX22_ENV */
 #include "netinet/udp.h"
-#if !defined(AFS_SGI62_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN60_ENV)
+#if !defined(AFS_SGI62_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN_ENV)
 #include "netinet/udp_var.h"
 #endif
 #if defined(AFS_HPUX102_ENV) || (defined(AFS_SGI62_ENV) && !defined(AFS_SGI64_ENV))
@@ -112,9 +114,6 @@ typedef unsigned short etap_event_t;
 #endif
 #ifdef AFS_LINUX22_ENV
 #include "h/sched.h"
-#if defined(FREEZER_H_EXISTS)
-#include "h/freezer.h"
-#endif
 #include "h/netdevice.h"
 #include "linux/if.h"
 #else
@@ -124,7 +123,7 @@ typedef unsigned short etap_event_t;
 #endif
 #include "net/if.h"
 #endif
-#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN60_ENV)
+#if !defined(AFS_HPUX110_ENV) && !defined(AFS_LINUX22_ENV) && !defined(AFS_DARWIN_ENV)
 #include "netinet/in_var.h"
 #endif /* ! AFS_HPUX110_ENV && ! AFS_LINUX22_ENV */
 #if !defined(AFS_LINUX22_ENV) && !defined(AFS_DUX40_ENV)
